//
//  AMMessage.h
//  AppMessagesKit
//
//  Created by Alberto García Hierro on 10/09/15.
//  Copyright © 2015 Rainy Cape S.L. All rights reserved.
//

#import <Foundation/Foundation.h>

typedef NS_ENUM(NSInteger, AMMessageState) {
    AMMessageStateNone,
    AMMessageStateNothingToPresent,
    AMMessageStateAlreadyPresented,
    AMMessageStateCantPresent,
    AMMessageStatePresented,
    AMMessageStateDone,
};

@class AMMessage;

typedef void (^AMMessageCompletion)(AMMessage* message, AMMessageState state, NSError* error);

@interface AMMessage : NSObject

@property (nonatomic, copy, readonly) NSString* ID;
@property (nonatomic, readonly) BOOL repeat;
@property (nonatomic, copy, readonly) NSString* title;
@property (nonatomic, copy, readonly) NSString* message;
@property (nonatomic, readonly) BOOL shouldBePresented;

@property (nonatomic, strong, readonly) NSDictionary* dictionary;

- (instancetype)initWithDictionary:(NSDictionary*)aDict NS_DESIGNATED_INITIALIZER;
- (instancetype)initWithJSONData:(NSData*)theData error:(NSError**)error;

- (BOOL)present;
- (BOOL)presentIfNeeded;
- (BOOL)presentWithCompletion:(AMMessageCompletion)completion;
- (BOOL)presentIfNeededWithCompletion:(AMMessageCompletion)completion;
- (void)setPresented:(BOOL)presented;

+ (void)messageWithURL:(NSURL*)theURL completion:(AMMessageCompletion)completion;
+ (void)messageWithRequest:(NSURLRequest*)theRequest completion:(AMMessageCompletion)completion;
+ (void)presentMessageWithURL:(NSURL*)theURL completion:(AMMessageCompletion)completion;
+ (void)presentMessageWithRequest:(NSURLRequest*)theRequest completion:(AMMessageCompletion)completion;

+ (void)scheduleMessagePresentation;
+ (void)scheduleMessagePresentationWithURL:(NSURL*)theURL interval:(NSTimeInterval)interval;
+ (void)unscheduleMessagePresentation;

@end
